myimagelib.pivLib.piv\_data
===========================

.. currentmodule:: myimagelib.pivLib

.. autoclass:: piv_data

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~piv_data.__init__
      ~piv_data.corrS1d
      ~piv_data.corrS2d
      ~piv_data.load_stack
      ~piv_data.mean_velocity
      ~piv_data.order_parameter
      ~piv_data.vacf
   
   

   
   
   